@@ -54,6 +54,7 @@ require AutoLoader;
 	KADM5_ADMIN_SERVICE
 	KADM5_API_VERSION_1
 	KADM5_API_VERSION_2
+	KADM5_API_VERSION_3
 	KADM5_API_VERSION_MASK
 	KADM5_ATTRIBUTES
 	KADM5_AUTH_ADD
@@ -189,9 +190,10 @@ require AutoLoader;
         KADM5_CONFIG_AUTH_NOFALLBACK
         KADM5_CONFIG_NO_AUTH
         KADM5_CONFIG_OLD_AUTH_GSSAPI
+	KRB5_KDB_ACCESS_ERROR
 );
 %EXPORT_TAGS = (constants => \@EXPORT_OK);
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 # Preloaded methods go here.
 
